import type {
	ILabelKeyRequest,
	DLabelKeyResultData,
	ContextRequest,
	DArchiveResultData,
	IArchiveListRequest,
	DStoreResultData,
	IStoreRequest,
	IArchiveForm,
	IPreviewRequest,
	IShareConfig,
	DShareConfigResultData,
	IStatistics,
	DPreviewResultData,
	IContextAddRequest
} from '@/types/api/context.type'
import { requestGET, requestPOST } from '@/types/api/index'
import { DForm } from '@/types/views/add.type'

export const getLabelKeyList = (data: ILabelKeyRequest) =>
	requestGET<ContextRequest, DLabelKeyResultData>('/commodity/product/archive/findKeyWordList', data)

export const getArchiveList = (data: IArchiveListRequest) =>
	requestGET<ContextRequest, DArchiveResultData[]>('/commodity/product/archive/list', data)

export const getStoreList = (data: IStoreRequest) =>
	requestGET<ContextRequest, DStoreResultData>('/commodity/product/archive/findProductList', data)

export const getArchiveFormDetails = (data: IArchiveForm) =>
	requestGET<ContextRequest, DArchiveResultData>('/commodity/product/archive/from', data)

export const getShareConfig = (data: IShareConfig) =>
	requestGET<ContextRequest, DShareConfigResultData>('https://zplma.caimei365.com/wx/sdk/config/data', data)

export const setStatistics = (data: IStatistics) =>
	requestGET<ContextRequest, { data: string }>('/user/record/Statistics', data)

export const addAllStatusForm = (data: DForm) =>
	requestPOST<ContextRequest, { data: string }>('/commodity/product/archive/add', data)

export const statisticAddContext = (data: IContextAddRequest) =>
	requestGET<ContextRequest, { data: string }>('/commodity/statistics/addPv', data)

export const previewData = (params: IPreviewRequest) => {
	return new Promise<DPreviewResultData>((resolve, reject) => {
		const { userId, type, id } = params
		fetch(`${import.meta.env.VITE_BASE_URL}/commodity/product/archive/${userId}/${type}/${id}/details`).then(res => res.json()).then(data => {
			resolve(data)
		}).catch(err => reject(err))
	})
}
