import { createWebHistory, createRouter } from 'vue-router'
import { staticRouter, notFoundPower } from './route'

import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
import { useUserInfoState } from '@/store/user/user';

const router = createRouter({
	history: createWebHistory(),
	routes: [...notFoundPower, ...staticRouter]
})

NProgress.configure({
  showSpinner: false
})

const whiteList: string[] = ['/login', '/preview']

router.beforeEach((to, _, next) => {
	const { token } = useUserInfoState()
	console.log(to)
	NProgress.start()
	if (to.meta.title) {
		document.title = to.meta.title as string
	}
	if (token) {
		if (to.path === '/login') {
			next('/database/index?t=0')
			return
		}
		next()
	} else {
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
			next()
      // 在免登录白名单，直接进入
    } else {
      next('/') // 否则全部重定向到登录页
    }
  }
})

router.afterEach(() => {
	NProgress.done()
})

export default router