import { DForm } from "../views/add.type";
import { ChangeTabEmit } from "../views/database.type";
import { DResultListData, IGlobalListRequest, IResultData } from "./index";

export type IPreviewResult = {
	fileName: string
	fileUrl: string
}

export type ILabelKeyResultData = { // 标签返回
	v: string;
	k: string;
}

export type INewLabelKeyResultData = { // 标签返回
	keyword: string;
	id: number;
}

export type DWaters = {
	ossUrl: string;
	ossName: string;
	fileName: string;
}

export interface DArchiveResultData extends IArchiveRequest { // 列表返回
	addTime?: string
	content?: string
	id?: string
	image?: string
	productType?: string
	shopName?: string
	waters?: Array<string> | string
	productArchiveId?: number
	productClassify?: number
	keywords?: string
	pv?: string
	link?: string
}

export type IStoreResultData = { // 商品返回类型
	image: string;
	id?: number
	productId: number
	productName: string
	shopName: string
} 

export type DShareConfigResultData = {
	appId?: string
	timestamp: number
	noncestr: string
	signature: string
}

export type DLabelKeyResultData = DResultListData<ILabelKeyResultData> 

export type DNewLabelKeyResultData = DResultListData<INewLabelKeyResultData> 

export type DStoreResultData = DResultListData<IStoreResultData>

export type IPreviewForm = {
	permission: number
	fileArchiveList: IPreviewResult[]
	waters: Array<string> | string
	productId: string
	id?: string
	image: string
}
export type DPreviewResultData = IResultData<IPreviewForm>
export interface ILabelKeyRequest extends IGlobalListRequest { // 参数
	v: string;
}
export interface INewLabelKeyRequest extends IGlobalListRequest {
	keyword: string;
}

export interface IArchiveRequest { // 参数
	title?: string
	userId?: string
	type?: ChangeTabEmit | string
	productId?: number | string
	stageStatus?: string | null
	allStatus?: string | number | null
	labelId?: string
	labelIds?: string
	spId?: string
	pageNum?: number
}

export type IArchiveListRequest = IArchiveRequest & Partial<IGlobalListRequest>

export type IContextAddRequest = {
	type: 1
	authorId: string
}
export interface IStoreRequest extends IGlobalListRequest {
	productName: string,
	shopName?: string
	productId?: number
}

export type IArchiveForm = {
	id: string
	userId?: string
	spId?: string
}

export type IPreviewRequest = {
	userId: string
	id: string
	type: ChangeTabEmit
}

export type IShareConfig = {
	appId: 'wx91c4152b60ca91a3', // 微信公众号appId
	url: string
}

export type IStatistics = {
	accessDuration: number
	pageType?: '67' | string
	pageLabel?: '内容库文件预览' | string
	pagePath: string
	headUserId?: string
	productArchiveId?: string
	accessClient: '0' | '1'
	userId: string
	productId: string
	shopId: string
	behaviorType: '1'
}

export interface ContextRequest {
	'/commodity/product/archive/findKeyWordList': ILabelKeyRequest
	'/commodity/product/archive/list': IArchiveListRequest
	'/commodity/product/archive/findProductList': IStoreRequest
	'/commodity/product/archive/from': IArchiveForm
	'https://zplma.caimei365.com/wx/sdk/config/data': IShareConfig
	'/user/record/Statistics': IStatistics
	'/commodity/product/archive/add': DForm
	'/home/findKeyWordList': INewLabelKeyRequest
	'/commodity/statistics/addPv': IContextAddRequest
}