import { reactive } from "vue";
import { DArchiveResultData, IArchiveRequest } from "../api/context.type";

export type DMenu = {
	text: string;
	value: number;
  subtitle?: string;
}

export interface DMenuList<T> {
	type: 'Double' | 'Singular'
	changeValue?: number
	options: Array<T & any>
	title: string
  isSearch?: boolean
}

export type ChangeEmitParams = {
	labelIds: DFindParams<IArchiveRequest, 'labelIds'>
	stageStatus: DFindParams<IArchiveRequest, 'stageStatus'>
	productId: DFindParams<IArchiveRequest, 'productId'>
}

export type SearchEmitParams = string

export type ChangeTabEmit = DFindParams<DScrollTab, 'type'>

export type DetailParams = {
  id?: string,
  type: ChangeTabEmit
  pageNum?: number
  content?: string
  allStatus?: DFindParams<IAllStatus, "allStatus">
}

export type DScrollTab = {
	type: '0' | '1' | '2' | '3' | '4' | '5' | '6' | '7'; // tab标签 
	text: '全部' | '图片' | '视频' | '文件' | '文章' | '百科' | '文本' | '话术';
}

export const tabList: Array<DScrollTab> = [
  {
    type: '0',
    text: "全部",
  },
  {
    type: '1',
    text: "图片",
  },
  {
    type: '2',
    text: "视频",
  },
  {
    type: '3',
    text: "文件",
  },
  {
    type: '4',
    text: "文本",
  },
  {
    type: '5',
    text: "话术",
  },
  {
    type: '6',
    text: "文章",
  },
  {
    type: '7',
    text: "百科",
  },
]
export const menuTypeOptions = reactive<Array<DMenuList<DMenu>>>([
  {
    type: "Double",
    title: "标签",
    options: [],
  },
  {
    type: "Singular",
    title: "商品",
    changeValue: 0,
    options: [],
  },
  {
    type: "Singular",
    title: "用户阶段",
    changeValue: 0,
    options: [
      {
        text: "用户阶段（全部）",
        value: 0,
      },
      {
        text: "认知阶段<span>（仅浏览过或咨询过一次该商品的用户）</span>",
        subtitle: "",
        value: 1,
      },
      {
        text: "兴趣阶段<span>（已咨询过该商品，且有过多次浏览搜索该商品的用户）</span>",
        subtitle: "",
        value: 2,
      },
      {
        text: "决策阶段<span>（多次询问商品且与同类商品比价，想要体验该商品的用户）</span>",
        subtitle: "",
        value: 3,
      },
      {
        text: "购买阶段<span>（正在走采购流程或已经将商品加入购物车的用户）</span>",
        subtitle: "",
        value: 4,
      },
    ],
  },
]);
export type IAllStatus = {
  allStatus: '1' | '2'
  value: '企业话术' | '个人话术'
}

export const allStatusList: IAllStatus[] = [
  { allStatus: '1', value: "企业话术" },
  { allStatus: '2', value: "个人话术" },
]
export interface DEmit {
	(e: 'handle-change-emit', n: ChangeEmitParams): void
	(e: 'handle-search-emit', n: NonNullable<DFindParams<IArchiveRequest, 'title'>>): void
	(e: 'handle-tab-emit', n: DScrollTab): void
  (e: 'handle-see-more', n: DetailParams): void
  (e: 'handle-all-status', n: DetailParams ): void
}

export interface DDataBaseListAll {
  type: ChangeTabEmit
  showMore: boolean
  dataList: DArchiveResultData[]
}

export type NonNullable<T> = T extends null | undefined ? never : T;

export type DFindArgs<T> = T extends ((e: any, n: infer R) => any) ? R : never

export type DFindParams<T, K extends keyof T> = T[K]

